# morsen.py
#-------------------------------------------------------------------------------------------------
# Lies ein Wort von der Kommandozeile (nur Großbuchstaben, keine Umlaute) und
# gib seine Kodierung im Morsecode
# oder seine Dekodierung aus dem Morsecode aus.
# Das Morsealphabet wird aus der Datei morsealphabet.txt gelesen.
# Die Datei enthält in jeder Zeile ein Zeichen und den zugehörigen Morsecode
# (durch Leerzeichen getrennt).
#-------------------------------------------------------------------------------------------------
import sys

# Teil 1: Einlesen des Morsealphabets ------------------------------------------------------------
# uebersetzerErzeugen() liest das Morsealphabet aus der Datei morsealphabet.txt.
# Sie gibt ein Dictionary mit der Zuordnung Buchstabe->Morsezeichen 
# und ein Dictionary mit der Zuordung Morsezeichen->Buchstabe zurück.
def uebersetzerErzeugen():
  eingabedatei = open('morsealphabet.txt','r')
  codeDict     = dict()       # Das Dictionary für die Kodierung in den Morsecode.
  decodeDict   = dict()       # Das Dictionary für die Dekodierung aus dem Morsecode.

  for zeile in eingabedatei:  # Gehe durch alle Zeilen der Eingabedatei.
     z = str.split(zeile)       # Teile die Zeile an Folgen von Leerzeichen auf.
     if len(z)<2: continue      # Falls dabei nicht mindestens 2 Teile herauskommen: ignoriere es.
     codeDict[z[0]]   = z[1]    # Trage die Zuordnung Zeichen->Morsezeichen in codeDict ein.
     decodeDict[z[1]] = z[0]    # Trage die Zuordung Morsezeichen->Zeichen in decodeDict ein.

  eingabedatei.close()
  return codeDict, decodeDict

# Teil 2: Kodieren bzw. Dekodieren eines Wortes --------------------------------------------------

# dekodiere(s, decodeDict) dekodiert den String s zeichenweise aus dem Morsecode.
# Das Dictionary decodeDict hat Morsezeichen als Schlüssel und Buchstaben als Werte.
def dekodiere(s, decodeDict):
  ergebnis = ''
  # Die Morsezeichen sind durch Leerzeichen getrennt und werden der Reihe nach einzeln dekodiert.
  for c in str.split(s):
    ergebnis += decodeDict[c]
  return ergebnis

# kodiere(s, codeDict) kodiert den String s zeichenweise in den Morsecode.
# Das Dictionary codeDict hat Buchstaben als Schlüssel und Morsezeichen als Werte.
def kodiere(s, codeDict):
  ergebnis = ''
  # Die Buchstaben werden der Reihe nach einzeln kodiert.
  for zeichen in s:
    ergebnis += codeDict[zeichen] + ' '
  return ergebnis

#-------------------------------------------------------------------------------------------------
# Das Testprogramm erzeugt die beiden Dictionaries zum Kodieren bzw. Dekodieren,
# und liest ein Wort von der Kommandozeile.
# Wenn das Wort mit . oder - beginnt, dann ist es im Morsecode und wird dekodiert.
# Anderenfalls wird es in den Morsecode kodiert.
# Am Ende wird das (de)kodierte Wort ausgegeben.
def testprogramm():
  codeDict, decodeDict = uebersetzerErzeugen()
  eingabe = sys.argv[1]
  # Falls die Eingabe mit . oder - anfängt, ist sie im Morsecode und wird dekodiert.
  if eingabe[0] in '.-':
      ausgabe = dekodiere(eingabe, decodeDict)
  # Sonst wird die Eingabe in den Morsecode kodiert.
  else: 
      ausgabe = kodiere(eingabe, codeDict)

  print(ausgabe)

#-------------------------------------------------------------------------------------------------
if __name__=='__main__': testprogramm()
#-------------------------------------------------------------------------------------------------
# python3 morsen.py INFORMATIK 
# .. -. ..-. --- .-. -- .- - .. -.- 
#
# python3 morsen.py '.. -. ..-. --- .-. -- .- - .. -.-'
# INFORMATIK

